@@ -42,51 +42,51 @@ __email__ = '''<inquiry@intoreflection.co>'''
 __status__ = '''Development'''  # "Prototype", "Development", "Production".
 
 
-class AnimateItem:  # pylint: disable=too-many-instance-attributes
+class AnimateItem:
     """Animates the canvas item by moving horizontally in one direction and loop."""
 
     def __init__(self, main_window, canvas_item):
         """Instantiates the Animate object.
 
         Args:
-            main_window: ______
-            canvas_item: ______
+            main_window (MainWindow): An instantiated MainWindow object.
+            canvas_item (CanvasItem): An instantiated CanvasItem object.
 
         """
-        self.status = main_window.main_frame.canvas_frame.canvas_status
-        self.canvas = main_window.main_frame.canvas_frame.canvas_landscape
-        self.terminate = False
-        self.canvas_item = canvas_item
-        self.canvas_item_width = canvas_item.total_width
-        self.distance = canvas_item.distance
-        self.distance_index = 0
-        self.scale = 1
+        self._status = main_window.main_frame.canvas_frame.canvas_status
+        self._canvas = main_window.main_frame.canvas_frame.canvas_landscape
+        self._terminate = False
+        self._canvas_item = canvas_item
+        self._canvas_item_width = canvas_item.total_width
+        self._distance = canvas_item.distance
+        self._distance_index = 0
+        # self._scale = 1  # IN DEVELOPMENT
 
     def start(self):
         """Moves a TCP/IP packet from item to another item and loop."""
-        self.canvas_item.show()
+        self._canvas_item.show()
 
         def _animate_forward():
-            if not self.terminate:
-                self.canvas.move(self.canvas_item.item_tag, 10 * self.scale, 0)
-                self.distance_index += 10 * self.scale
-                if self.distance_index >= self.distance - self.canvas_item_width:
-                    start_pos = self.distance - self.canvas_item_width
-                    self.canvas.move(self.canvas_item.item_tag, start_pos * -1, 0)
-                    self.distance_index = 0
-                self.canvas.after(25, _animate_forward)
+            if not self._terminate:
+                self._canvas.move(self._canvas_item.item_tag, 10, 0)
+                self._distance_index += 10
+                if self._distance_index >= self._distance - self._canvas_item_width:
+                    start_pos = self._distance - self._canvas_item_width
+                    self._canvas.move(self._canvas_item.item_tag, start_pos * -1, 0)
+                    self._distance_index = 0
+                self._canvas.after(25, _animate_forward)
 
         _animate_forward()  # note, the animation will be threaded, so after invoking this method, it continues directly
 
     def stop(self):
         """Stop moving the TCP/IP packet and cleanup."""
-        self.terminate = True
-        self.canvas.delete(self.canvas_item.item_tag)
+        self._terminate = True
+        self._canvas.delete(self._canvas_item.item_tag)
 
     def pause(self):
         """Temporarily pause moving the TCP/IP package."""
-        self.canvas.itemconfig(self.canvas_item.item_tag, state='hidden')
+        self._canvas.itemconfig(self._canvas_item.item_tag, state='hidden')
 
     def resume(self):
         """Resume moving the TCP/IP package."""
-        self.canvas.itemconfig(self.canvas_item.item_tag, state='normal')
+        self._canvas.itemconfig(self._canvas_item.item_tag, state='normal')
