@@ -128,7 +128,7 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
     def _set_size_window(self):
         screen_width = self.winfo_screenwidth()  # width of the computer screen
         screen_height = self.winfo_screenheight()  # height of the computer screen
-        self.scale = determine_scale(screen_width)  # scale is nowhere used because it's in development
+        self.scale = determine_scale(screen_width)  # IN DEVELOPMENT
         win_width = WINDOW_WIDTH * self.scale  # width of the main window
         win_height = WINDOW_HEIGHT * self.scale  # height of the main window
         start_x = (screen_width / 2) - (win_width / 2)
@@ -304,7 +304,7 @@ class MainWindow(tk.Tk, LoggerMixin):  # pylint: disable=too-many-instance-attri
 
 
 class CommandWindow(tk.Toplevel):
-    """Represents an interface for the user to send commands to last host and show output."""
+    """Represents an interface for the user to send commands to destination host and show output."""
 
     def __init__(self, parent, *args, **kwargs):
         """Instantiates the TopLevel object."""
